class ListOperations:
    @staticmethod

    def all_caps(list_to: list[str]) -> list[str]:
        ls = []
        
        for items in list_to:
            ls.append(items.capitalize())
        
        return ls
    def all_uppers(list_to: list[str]) -> list[str]:
        ls = []
        
        for items in list_to:
            ls.append(items.upper())
        
        return ls
    def all_lowers(list_to: list[str]) -> list[str]:
        ls = []
        
        for items in list_to:
            ls.append(items.lower())
        
        return ls
    def all_rands(list_to: list[str], length: int = None) -> list[str]:
        import random
        import string

        ls = []

        if length == None:
            for items in list_to:
                char_rule = string.ascii_letters + string.digits + string.punctuation

                item = ''.join(random.choices(char_rule))
                ls.append(item)
        else:
            for items in list_to:
                char_rule = string.ascii_letters + string.digits + string.punctuation

                item = ''.join(random.choices(char_rule, k=length))
                ls.append(item)

        return ls


class Fibbonaccis:
    @staticmethod

    def lim_fibbos(start1: int, start2: int, limit: int):
        sequence = [start1, start2]
    
        while len(sequence) < limit:
            next_val = sequence[-1] + sequence[-2]
            sequence.append(next_val)
        
        return sequence
    def inf_fibbos(start1: int, start2: int, ignore_warning: bool = False):
        import math

        if ignore_warning == False:
            print("Warning, the following program may crash your device..")
        else:
            pass

        limit = math.inf
        sequence = [start1, start2]
    
        while len(sequence) < limit:
            next_val = sequence[-1] + sequence[-2]
            sequence.append(next_val)
        
        return sequence


from typing import Union, List, Tuple
import sympy

class Numericals:
    @staticmethod

    def are_odd_or_even(collections_to_check: Union[List, Tuple], figure_out: str, return_how: str):
        ls = []

        if figure_out.lower() not in ["even", "odd"]:
            raise ValueError("figure_out parameter must be 'even' or 'odd'.")

        for nums in collections_to_check:
            if not isinstance(nums, int):
                raise TypeError("Items in the given list/tuple must all be integers in the collections_to_check parameter.")
            else:
                if nums % 2 == 0:
                    if figure_out.lower() == "even":
                        ls.append("True")
                    else:
                        ls.append("False")
                else:
                    if figure_out.lower() == "even":
                        ls.append("False")
                    else:
                        ls.append("True")
        
        if return_how.lower() == "list":
            return list(ls)
        elif return_how.lower() == "tuple":
            return tuple(ls)
        elif return_how.lower() == "set":
            raise ValueError("Cannot return set due to possible duplicate result conflicts in return_how parameter.")
        else:
            raise ValueError("Cannot accept anything except list/tuple in return_how parameter.")
    def is_odd_or_even(num: int, figure_out: str):
        if figure_out.lower() not in ["even", "odd"]:
            raise TypeError("figure_out parameter must be 'even' or 'odd'.")
        else:
            if num % 2 == 0:
                if figure_out.lower() == "even":
                    return True
                else:
                    return False
            else:
                if figure_out.lower() == "even":
                    return False
                else:
                    return True
    def is_prime_or_composite(num: int, figure_out: str):
        if figure_out.lower() not in ["prime", "composite"]:
            raise TypeError("figure_out parameter must be 'prime' or 'composite'.")
        
        return sympy.isprime(num)
    def are_prime_or_composite(collections_to_check: Union[List, Tuple], figure_out: str, return_how: str):
        if figure_out.lower() not in ["prime", "composite"]:
            raise TypeError("figure_out parameter must be 'prime' or 'composite'.")
        
        for nums in collections_to_check:
            if not isinstance(nums, int):
                raise TypeError("Items in the given list/tuple must all be integers in the collections_to_check parameter.")
          
            ls = []
            var = sympy.isprime(nums)

            if var == True:
                if figure_out == "prime":
                    ls.append("True")
                else:
                    ls.append("False")
            else:
                if figure_out == "prime":
                    ls.append("False")
                else:
                    ls.append("True")
        
        return ls


import os

class RenameVarsFiles:
    def rename(file: str, name: str):
        os.rename(file, name)
    def renameS(files: list[str] | tuple[str] | set[str], names: list[str] | tuple[str] | set[str]):
        if len(files) != len(names):
            raise IndexError("The amount of files to be renamed does not match the amout of names requested")
        
        for file, name in zip(files, names):
            os.rename(file, name)


import os

class DeleteVarsFiles:  
    def delete(file: str):
        os.remove(file)
    def deleteS(files: list[str] | tuple[str] | set[str]):
        for file in files:
            os.rename(file)


from .string_utils.list import ListOperations
from .num_utils.fibbonaccis import Fibbonaccis
from .low_level.deletes import DeleteVarsFiles
from .low_level.renames import RenameVarsFiles
from .num_utils.numericals import Numericals

__version__ = "0.1.2"
__all__ = ["ListOperations", "Fibbonaccis", "DeleteVarsFiles", "RenameVarsFiles", "Numericals"]